==> zio-aws-gamelift_2.12-5.20.7.1-sources.jar: zio/aws/gamelift/model/DescribeFleetCapacityRequest.scala <==
package zio.aws.gamelift.model
import zio.aws.gamelift.model.primitives.{
  NonZeroAndMaxString,
  PositiveInteger,
  FleetIdOrArn
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeFleetCapacityRequest(
    fleetIds: Optional[Iterable[FleetIdOrArn]] = Optional.Absent,
    limit: Optional[PositiveInteger] = Optional.Absent,
    nextToken: Optional[NonZeroAndMaxString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.gamelift.model.DescribeFleetCapacityRequest = {
    import DescribeFleetCapacityRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.gamelift.model.DescribeFleetCapacityRequest
      .builder()
      .optionallyWith(
        fleetIds.map(value =>
          value.map { item =>
            FleetIdOrArn.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.fleetIds)
      .optionallyWith(
        limit.map(value => PositiveInteger.unwrap(value): Integer)
      )(_.limit)
      .optionallyWith(
        nextToken.map(value =>
          NonZeroAndMaxString.unwrap(value): java.lang.String
        )
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.gamelift.model.DescribeFleetCapacityRequest.ReadOnly =
    zio.aws.gamelift.model.DescribeFleetCapacityRequest.wrap(buildAwsValue())
}
object DescribeFleetCapacityRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.gamelift.model.DescribeFleetCapacityRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.gamelift.model.DescribeFleetCapacityRequest =
      zio.aws.gamelift.model.DescribeFleetCapacityRequest(
        fleetIds.map(value => value),
        limit.map(value => value),
        nextToken.map(value => value)
      )
    def fleetIds: Optional[List[FleetIdOrArn]]
    def limit: Optional[PositiveInteger]
    def nextToken: Optional[NonZeroAndMaxString]
    def getFleetIds: ZIO[Any, AwsError, List[FleetIdOrArn]] =
      AwsError.unwrapOptionField("fleetIds", fleetIds)
    def getLimit: ZIO[Any, AwsError, PositiveInteger] =
      AwsError.unwrapOptionField("limit", limit)
    def getNextToken: ZIO[Any, AwsError, NonZeroAndMaxString] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.gamelift.model.DescribeFleetCapacityRequest
  ) extends zio.aws.gamelift.model.DescribeFleetCapacityRequest.ReadOnly {
    override val fleetIds: Optional[List[FleetIdOrArn]] = zio.aws.core.internal
      .optionalFromNullable(impl.fleetIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.gamelift.model.primitives.FleetIdOrArn(item)
        }.toList
      )
    override val limit: Optional[PositiveInteger] = zio.aws.core.internal
      .optionalFromNullable(impl.limit())
      .map(value => zio.aws.gamelift.model.primitives.PositiveInteger(value))
    override val nextToken: Optional[NonZeroAndMaxString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.nextToken())
        .map(value =>
          zio.aws.gamelift.model.primitives.NonZeroAndMaxString(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.gamelift.model.DescribeFleetCapacityRequest
  ): zio.aws.gamelift.model.DescribeFleetCapacityRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-gamelift_2.13-5.17.116.2-sources.jar: zio/aws/gamelift/model/DescribeFleetCapacityRequest.scala <==
package zio.aws.gamelift.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.gamelift.model.primitives.{
  NonZeroAndMaxString,
  PositiveInteger,
  FleetIdOrArn
}
import scala.jdk.CollectionConverters._
final case class DescribeFleetCapacityRequest(
    fleetIds: Option[Iterable[FleetIdOrArn]] = None,
    limit: Option[PositiveInteger] = None,
    nextToken: Option[NonZeroAndMaxString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.gamelift.model.DescribeFleetCapacityRequest = {
    import DescribeFleetCapacityRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.gamelift.model.DescribeFleetCapacityRequest
      .builder()
      .optionallyWith(
        fleetIds.map(value =>
          value.map { item =>
            FleetIdOrArn.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.fleetIds)
      .optionallyWith(
        limit.map(value => PositiveInteger.unwrap(value): Integer)
      )(_.limit)
      .optionallyWith(
        nextToken.map(value =>
          NonZeroAndMaxString.unwrap(value): java.lang.String
        )
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.gamelift.model.DescribeFleetCapacityRequest.ReadOnly =
    zio.aws.gamelift.model.DescribeFleetCapacityRequest.wrap(buildAwsValue())
}
object DescribeFleetCapacityRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.gamelift.model.DescribeFleetCapacityRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.gamelift.model.DescribeFleetCapacityRequest =
      zio.aws.gamelift.model.DescribeFleetCapacityRequest(
        fleetIds.map(value => value),
        limit.map(value => value),
        nextToken.map(value => value)
      )
    def fleetIds: Option[List[FleetIdOrArn]]
    def limit: Option[PositiveInteger]
    def nextToken: Option[NonZeroAndMaxString]
    def getFleetIds: ZIO[Any, AwsError, List[FleetIdOrArn]] =
      AwsError.unwrapOptionField("fleetIds", fleetIds)
    def getLimit: ZIO[Any, AwsError, PositiveInteger] =
      AwsError.unwrapOptionField("limit", limit)
    def getNextToken: ZIO[Any, AwsError, NonZeroAndMaxString] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.gamelift.model.DescribeFleetCapacityRequest
  ) extends zio.aws.gamelift.model.DescribeFleetCapacityRequest.ReadOnly {
    override val fleetIds: Option[List[FleetIdOrArn]] = scala
      .Option(impl.fleetIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.gamelift.model.primitives.FleetIdOrArn(item)
        }.toList
      )
    override val limit: Option[PositiveInteger] = scala
      .Option(impl.limit())
      .map(value => zio.aws.gamelift.model.primitives.PositiveInteger(value))
    override val nextToken: Option[NonZeroAndMaxString] = scala
      .Option(impl.nextToken())
      .map(value =>
        zio.aws.gamelift.model.primitives.NonZeroAndMaxString(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.gamelift.model.DescribeFleetCapacityRequest
  ): zio.aws.gamelift.model.DescribeFleetCapacityRequest.ReadOnly = new Wrapper(
    impl
  )
}
